@@ -117,6 +117,7 @@ madlib.lm <- function (formula, data, na.action = NULL,
 
     r.grp.cols <- gsub("\"", "", arraydb.to.arrayr(params$grp.str,
                                                    "character", n))
+    r.nobs <- res$num_rows_processed
     r.grp.expr <- params$grp.expr
     r.has.intercept <- params$has.intercept # do we have an intercept
     ## r.ind.vars <- gsub("\"", "", params$ind.vars)
@@ -187,7 +188,7 @@ madlib.lm <- function (formula, data, na.action = NULL,
             rst[[i]]$data <- origin.data
 
         rst[[i]]$origin.data <- origin.data
-        rst[[i]]$nobs <- nrow(rst[[i]]$data)
+        rst[[i]]$nobs <- r.nobs[i]
 
         class(rst[[i]]) <- "lm.madlib" # A single model class
 
